package java.util.stream;

import java.util.Arrays;
import java.util.AbstractSet;
import java.util.AbstractMap;
import java.util.DoubleSummaryStatistics;
import java.util.LongSummaryStatistics;
import java.util.IntSummaryStatistics;
import java.util.function.Predicate;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.ConcurrentMap;
import java.util.function.BiConsumer;
import java.util.Objects;
import java.util.HashMap;
import java.util.function.Consumer;
import java.util.function.ToDoubleFunction;
import java.util.function.ToLongFunction;
import java.util.function.ToIntFunction;
import java.util.Optional;
import java.util.Comparator;
import java.util.Collections;
import java.util.EnumSet;
import java.util.Iterator;
import java.util.Map;
import java.util.StringJoiner;
import java.util.HashSet;
import java.util.ArrayList;
import java.util.List;
import java.util.Collection;
import java.util.function.Supplier;
import java.util.function.Function;
import java.util.function.BinaryOperator;
import java.util.Set;

public final class Collectors
{
    static final Set<Collector.Characteristics> CH_CONCURRENT_ID;
    static final Set<Collector.Characteristics> CH_CONCURRENT_NOID;
    static final Set<Collector.Characteristics> CH_ID;
    static final Set<Collector.Characteristics> CH_UNORDERED_ID;
    static final Set<Collector.Characteristics> CH_NOID;
    
    private Collectors() {
    }
    
    private static <T> BinaryOperator<T> throwingMerger() {
        return (o, p1)/* java.lang.Object,java.lang.Object, */ -> {
            new IllegalStateException(String.format("Duplicate key %s", new Object[] { o }));
            throw;
        };
    }
    
    private static <I, R> Function<I, R> castingIdentity() {
        return o/* java.lang.Object, */ -> o;
    }
    
    public static <T, C extends Collection<T>> Collector<T, ?, C> toCollection(Supplier<C> supplier) {
        return new Collectors.CollectorImpl(supplier, Collection::add, (collection, collection2)/* java.util.Collection,java.util.Collection, */ -> {
            collection.addAll(collection2);
            return collection;
        }, Collectors.CH_ID);
    }
    
    public static <T> Collector<T, ?, List<T>> toList() {
        return new Collectors.CollectorImpl(ArrayList::new, List::add, (list, list2)/* java.util.List,java.util.List, */ -> {
            list.addAll(list2);
            return list;
        }, Collectors.CH_ID);
    }
    
    public static <T> Collector<T, ?, Set<T>> toSet() {
        return new Collectors.CollectorImpl(HashSet::new, Set::add, (set, set2)/* java.util.Set,java.util.Set, */ -> {
            set.addAll(set2);
            return set;
        }, Collectors.CH_UNORDERED_ID);
    }
    
    public static Collector<CharSequence, ?, String> joining() {
        return new Collectors.CollectorImpl(StringBuilder::new, StringBuilder::append, (sb, s)/* java.lang.StringBuilder,java.lang.StringBuilder, */ -> {
            sb.append(s);
            return sb;
        }, StringBuilder::toString, Collectors.CH_NOID);
    }
    
    public static Collector<CharSequence, ?, String> joining(CharSequence charSequence) {
        return joining(charSequence, "", "");
    }
    
    public static Collector<CharSequence, ?, String> joining(CharSequence charSequence, CharSequence charSequence2, CharSequence charSequence3) {
        return new Collectors.CollectorImpl(()/*  */ -> new StringJoiner(p0, p1, p2), StringJoiner::add, StringJoiner::merge, StringJoiner::toString, Collectors.CH_NOID);
    }
    
    private static <K, V, M extends Map<K, V>> BinaryOperator<M> mapMerger(BinaryOperator<V> binaryOperator) {
        return (map, map2)/* java.util.Map,java.util.Map, */ -> {
            Iterator<Object> iterator = map2.entrySet().iterator();
            while (iterator.hasNext()) {
                Map.Entry<Object, Object> entry = (Map.Entry)iterator.next();
                map.merge(entry.getKey(), entry.getValue(), p0);
            }
            return map;
        };
    }
    
    public static <T, U, A, R> Collector<T, ?, R> mapping(Function<? super T, ? extends U> function, Collector<? super U, A, R> collector2) {
        return new Collectors.CollectorImpl(collector2.supplier(), (o, o2)/* java.lang.Object,java.lang.Object, */ -> {
            collector2.accumulator();
            biConsumer.accept(o, p0.apply(o2));
            return;
        }, collector2.combiner(), collector2.finisher(), collector2.characteristics());
    }
    
    public static <T, A, R, RR> Collector<T, A, RR> collectingAndThen(Collector<T, A, R> collector, Function<R, RR> after) {
        Set<Object> c = collector.characteristics();
        if (c.contains(Collector.Characteristics.IDENTITY_FINISH)) {
            if (c.size() == 1) {
                c = Collectors.CH_NOID;
            }
            else {
                EnumSet<Enum> copy = EnumSet.copyOf(c);
                copy.remove(Collector.Characteristics.IDENTITY_FINISH);
                c = Collections.unmodifiableSet(copy);
            }
        }
        return new Collectors.CollectorImpl(collector.supplier(), collector.accumulator(), collector.combiner(), collector.finisher().andThen(after), c);
    }
    
    public static <T> Collector<T, ?, Long> counting() {
        return reducing(Long.valueOf(0L), p0/* java.lang.Object, */ -> Long.valueOf(1L), Long::sum);
    }
    
    public static <T> Collector<T, ?, Optional<T>> minBy(Comparator<? super T> comparator) {
        return reducing(BinaryOperator.minBy(comparator));
    }
    
    public static <T> Collector<T, ?, Optional<T>> maxBy(Comparator<? super T> comparator) {
        return reducing(BinaryOperator.maxBy(comparator));
    }
    
    public static <T> Collector<T, ?, Integer> summingInt(ToIntFunction<? super T> toIntFunction) {
        return new Collectors.CollectorImpl(()/*  */ -> new int[1], (array, o)/* int[],java.lang.Object, */ -> {
            int n;
            array[n] += p0.applyAsInt(o);
            return;
        }, (array2, array3)/* int[],int[], */ -> {
            int n2;
            array2[n2] += array3[0];
            return array2;
        }, array4/* int[], */ -> Integer.valueOf(array4[0]), Collectors.CH_NOID);
    }
    
    public static <T> Collector<T, ?, Long> summingLong(ToLongFunction<? super T> toLongFunction) {
        return new Collectors.CollectorImpl(()/*  */ -> new long[1], (array, o)/* long[],java.lang.Object, */ -> {
            int n;
            array[n] += p0.applyAsLong(o);
            return;
        }, (array2, array3)/* long[],long[], */ -> {
            int n2;
            array2[n2] += array3[0];
            return array2;
        }, array4/* long[], */ -> Long.valueOf(array4[0]), Collectors.CH_NOID);
    }
    
    public static <T> Collector<T, ?, Double> summingDouble(ToDoubleFunction<? super T> toDoubleFunction) {
        return new Collectors.CollectorImpl(()/*  */ -> new double[3], (array, o)/* double[],java.lang.Object, */ -> {
            sumWithCompensation(array, p0.applyAsDouble(o));
            int n;
            array[n] += p0.applyAsDouble(o);
            return;
        }, (array2, array3)/* double[],double[], */ -> {
            sumWithCompensation(array2, array3[0]);
            int n2;
            array2[n2] += array3[2];
            return sumWithCompensation(array2, array3[1]);
        }, array4/* double[], */ -> Double.valueOf(computeFinalSum(array4)), Collectors.CH_NOID);
    }
    
    static double[] sumWithCompensation(double[] array, double n) {
        double n2 = n - array[1];
        double n3 = array[0];
        double n4 = n3 + n2;
        array[1] = n4 - n3 - n2;
        array[0] = n4;
        return array;
    }
    
    static double computeFinalSum(double[] array) {
        double v = array[0] + array[1];
        double v2 = array[array.length - 1];
        if (Double.isNaN(v) && Double.isInfinite(v2)) {
            return v2;
        }
        return v;
    }
    
    public static <T> Collector<T, ?, Double> averagingInt(ToIntFunction<? super T> toIntFunction) {
        return new Collectors.CollectorImpl(()/*  */ -> new long[2], (array, o)/* long[],java.lang.Object, */ -> {
            int n;
            array[n] += (long)p0.applyAsInt(o);
            int n2;
            ++array[n2];
            return;
        }, (array2, array3)/* long[],long[], */ -> {
            int n3;
            array2[n3] += array3[0];
            int n4;
            array2[n4] += array3[1];
            return array2;
        }, array4/* long[], */ -> Double.valueOf((array4[1] == 0L) ? 0.0 : ((double)array4[0] / (double)array4[1])), Collectors.CH_NOID);
    }
    
    public static <T> Collector<T, ?, Double> averagingLong(ToLongFunction<? super T> toLongFunction) {
        return new Collectors.CollectorImpl(()/*  */ -> new long[2], (array, o)/* long[],java.lang.Object, */ -> {
            int n;
            array[n] += p0.applyAsLong(o);
            int n2;
            ++array[n2];
            return;
        }, (array2, array3)/* long[],long[], */ -> {
            int n3;
            array2[n3] += array3[0];
            int n4;
            array2[n4] += array3[1];
            return array2;
        }, array4/* long[], */ -> Double.valueOf((array4[1] == 0L) ? 0.0 : ((double)array4[0] / (double)array4[1])), Collectors.CH_NOID);
    }
    
    public static <T> Collector<T, ?, Double> averagingDouble(ToDoubleFunction<? super T> toDoubleFunction) {
        return new Collectors.CollectorImpl(()/*  */ -> new double[4], (array, o)/* double[],java.lang.Object, */ -> {
            sumWithCompensation(array, p0.applyAsDouble(o));
            int n;
            ++array[n];
            int n2;
            array[n2] += p0.applyAsDouble(o);
            return;
        }, (array2, array3)/* double[],double[], */ -> {
            sumWithCompensation(array2, array3[0]);
            sumWithCompensation(array2, array3[1]);
            int n3;
            array2[n3] += array3[2];
            int n4;
            array2[n4] += array3[3];
            return array2;
        }, array4/* double[], */ -> Double.valueOf((array4[2] == 0.0) ? 0.0 : (computeFinalSum(array4) / array4[2])), Collectors.CH_NOID);
    }
    
    public static <T> Collector<T, ?, T> reducing(T t, BinaryOperator<T> binaryOperator) {
        return new Collectors.CollectorImpl(boxSupplier(t), (array, o)/* java.lang.Object[],java.lang.Object, */ -> array[0] = p1.apply(array[0], o), (array2, array3)/* java.lang.Object[],java.lang.Object[], */ -> {
            array2[0] = p1.apply(array2[0], array3[0]);
            return array2;
        }, array4/* java.lang.Object[], */ -> array4[0], Collectors.CH_NOID);
    }
    
    private static <T> Supplier<T[]> boxSupplier(T t) {
        return ()/*  */ -> (Object[])new Object[] { p0 };
    }
    
    public static <T> Collector<T, ?, Optional<T>> reducing(BinaryOperator<T> binaryOperator) {
        class OptionalBox implements Consumer<T>
        {
            T value;
            boolean present;
            
            OptionalBox() {
                this.value = null;
                this.present = false;
            }
            
            @Override
            public void accept(T value) {
                if (this.present) {
                    this.value = p0.apply(this.value, value);
                }
                else {
                    this.value = value;
                    this.present = true;
                }
            }
        }
        return new Collectors.CollectorImpl(()/*  */ -> new OptionalBox(), Collectors.1OptionalBox::accept, (optionalBox, optionalBox2)/* java.util.stream.Collectors.OptionalBox,java.util.stream.Collectors.OptionalBox, */ -> {
            if (optionalBox2.present) {
                optionalBox.accept(optionalBox2.value);
                return optionalBox;
            }
            return optionalBox;
        }, optionalBox3/* java.util.stream.Collectors.OptionalBox, */ -> Optional.ofNullable(optionalBox3.value), Collectors.CH_NOID);
    }
    
    public static <T, U> Collector<T, ?, U> reducing(U u, Function<? super T, ? extends U> function, BinaryOperator<U> binaryOperator) {
        return new Collectors.CollectorImpl(boxSupplier(u), (array, o)/* java.lang.Object[],java.lang.Object, */ -> array[0] = p2.apply(array[0], p1.apply(o)), (array2, array3)/* java.lang.Object[],java.lang.Object[], */ -> {
            array2[0] = p2.apply(array2[0], array3[0]);
            return array2;
        }, array4/* java.lang.Object[], */ -> array4[0], Collectors.CH_NOID);
    }
    
    public static <T, K> Collector<T, ?, Map<K, List<T>>> groupingBy(Function<? super T, ? extends K> function) {
        return groupingBy(function, toList());
    }
    
    public static <T, K, A, D> Collector<T, ?, Map<K, D>> groupingBy(Function<? super T, ? extends K> function, Collector<? super T, A, D> collector) {
        return groupingBy(function, HashMap::new, collector);
    }
    
    public static <T, K, D, A, M extends Map<K, D>> Collector<T, ?, M> groupingBy(Function<? super T, ? extends K> function, Supplier<M> supplier, Collector<? super T, A, D> collector3) {
        BiConsumer<Object, Object> biConsumer = (map, o)/* java.util.Map,java.lang.Object, */ -> {
            collector3.supplier();
            collector3.accumulator();
            biConsumer2.accept(map.computeIfAbsent(Objects.requireNonNull(p0.apply(o), "element cannot be mapped to a null key"), p1/* java.lang.Object, */ -> p1.get()), o);
            return;
        };
        BinaryOperator<A> mapMerger = mapMerger(collector3.combiner());
        if (collector3.characteristics().contains(Collector.Characteristics.IDENTITY_FINISH)) {
            return new Collectors.CollectorImpl(supplier, biConsumer, mapMerger, Collectors.CH_ID);
        }
        return new Collectors.CollectorImpl(supplier, biConsumer, mapMerger, map2/* java.util.Map, */ -> {
            collector3.finisher();
            map2.replaceAll((p1, o4)/* java.lang.Object,java.lang.Object, */ -> p0.apply(o4));
            return map2;
        }, Collectors.CH_NOID);
    }
    
    public static <T, K> Collector<T, ?, ConcurrentMap<K, List<T>>> groupingByConcurrent(Function<? super T, ? extends K> function) {
        return groupingByConcurrent(function, ConcurrentHashMap::new, toList());
    }
    
    public static <T, K, A, D> Collector<T, ?, ConcurrentMap<K, D>> groupingByConcurrent(Function<? super T, ? extends K> function, Collector<? super T, A, D> collector) {
        return groupingByConcurrent(function, ConcurrentHashMap::new, collector);
    }
    
    public static <T, K, A, D, M extends ConcurrentMap<K, D>> Collector<T, ?, M> groupingByConcurrent(Function<? super T, ? extends K> function, Supplier<M> supplier, Collector<? super T, A, D> collector2) {
        collector2.supplier();
        collector2.accumulator();
        BinaryOperator<A> mapMerger = mapMerger(collector2.combiner());
        BiConsumer<Object, Object> biConsumer;
        if (collector2.characteristics().contains(Collector.Characteristics.CONCURRENT)) {
            biConsumer = ((concurrentMap2, o3)/* java.util.concurrent.ConcurrentMap,java.lang.Object, */ -> var_4_0D.accept(concurrentMap2.computeIfAbsent(Objects.requireNonNull(p0.apply(o3), "element cannot be mapped to a null key"), p1/* java.lang.Object, */ -> var_3_06.get()), o3));
        }
        else {
            biConsumer = ((concurrentMap, o)/* java.util.concurrent.ConcurrentMap,java.lang.Object, */ -> {
                Object o2 = concurrentMap.computeIfAbsent(Objects.requireNonNull(p0.apply(o), "element cannot be mapped to a null key"), p1/* java.lang.Object, */ -> var_3_06.get());
                synchronized (o2) {
                    var_4_0D.accept(o2, o);
                }
                return;
            });
        }
        if (collector2.characteristics().contains(Collector.Characteristics.IDENTITY_FINISH)) {
            return new Collectors.CollectorImpl(supplier, biConsumer, mapMerger, Collectors.CH_CONCURRENT_ID);
        }
        return new Collectors.CollectorImpl(supplier, biConsumer, mapMerger, concurrentMap3/* java.util.concurrent.ConcurrentMap, */ -> {
            collector2.finisher();
            concurrentMap3.replaceAll((p1, o6)/* java.lang.Object,java.lang.Object, */ -> p0.apply(o6));
            return concurrentMap3;
        }, Collectors.CH_CONCURRENT_NOID);
    }
    
    public static <T> Collector<T, ?, Map<Boolean, List<T>>> partitioningBy(Predicate<? super T> predicate) {
        return partitioningBy(predicate, toList());
    }
    
    public static <T, D, A> Collector<T, ?, Map<Boolean, D>> partitioningBy(Predicate<? super T> predicate, Collector<? super T, A, D> collector3) {
        BiConsumer<Object, Object> biConsumer = (partition, o)/* java.util.stream.Collectors.Partition,java.lang.Object, */ -> {
            collector3.accumulator();
            biConsumer2.accept(p0.test(o) ? partition.forTrue : partition.forFalse, o);
            return;
        };
        BinaryOperator<Object> binaryOperator = (partition2, partition3)/* java.util.stream.Collectors.Partition,java.util.stream.Collectors.Partition, */ -> {
            collector3.combiner();
            return new Collectors.Partition(binaryOperator2.apply(partition2.forTrue, partition3.forTrue), binaryOperator2.apply(partition2.forFalse, partition3.forFalse));
        };
        Supplier<Object> supplier = ()/*  */ -> new Collectors.Partition(p1.supplier().get(), p1.supplier().get());
        if (collector3.characteristics().contains(Collector.Characteristics.IDENTITY_FINISH)) {
            return new Collectors.CollectorImpl(supplier, biConsumer, binaryOperator, Collectors.CH_ID);
        }
        return new Collectors.CollectorImpl(supplier, biConsumer, binaryOperator, partition4/* java.util.stream.Collectors.Partition, */ -> new Collectors.Partition(p1.finisher().apply(partition4.forTrue), p1.finisher().apply(partition4.forFalse)), Collectors.CH_NOID);
    }
    
    public static <T, K, U> Collector<T, ?, Map<K, U>> toMap(Function<? super T, ? extends K> function, Function<? super T, ? extends U> function2) {
        return toMap(function, function2, throwingMerger(), HashMap::new);
    }
    
    public static <T, K, U> Collector<T, ?, Map<K, U>> toMap(Function<? super T, ? extends K> function, Function<? super T, ? extends U> function2, BinaryOperator<U> binaryOperator) {
        return toMap(function, function2, binaryOperator, HashMap::new);
    }
    
    public static <T, K, U, M extends Map<K, U>> Collector<T, ?, M> toMap(Function<? super T, ? extends K> function, Function<? super T, ? extends U> function2, BinaryOperator<U> binaryOperator, Supplier<M> supplier) {
        return new Collectors.CollectorImpl(supplier, (map, o)/* java.util.Map,java.lang.Object, */ -> map.merge(p0.apply(o), p1.apply(o), p2), mapMerger(binaryOperator), Collectors.CH_ID);
    }
    
    public static <T, K, U> Collector<T, ?, ConcurrentMap<K, U>> toConcurrentMap(Function<? super T, ? extends K> function, Function<? super T, ? extends U> function2) {
        return toConcurrentMap(function, function2, throwingMerger(), ConcurrentHashMap::new);
    }
    
    public static <T, K, U> Collector<T, ?, ConcurrentMap<K, U>> toConcurrentMap(Function<? super T, ? extends K> function, Function<? super T, ? extends U> function2, BinaryOperator<U> binaryOperator) {
        return toConcurrentMap(function, function2, binaryOperator, ConcurrentHashMap::new);
    }
    
    public static <T, K, U, M extends ConcurrentMap<K, U>> Collector<T, ?, M> toConcurrentMap(Function<? super T, ? extends K> function, Function<? super T, ? extends U> function2, BinaryOperator<U> binaryOperator, Supplier<M> supplier) {
        return new Collectors.CollectorImpl(supplier, (concurrentMap, o)/* java.util.concurrent.ConcurrentMap,java.lang.Object, */ -> concurrentMap.merge(p0.apply(o), p1.apply(o), p2), mapMerger(binaryOperator), Collectors.CH_CONCURRENT_ID);
    }
    
    public static <T> Collector<T, ?, IntSummaryStatistics> summarizingInt(ToIntFunction<? super T> toIntFunction) {
        return new Collectors.CollectorImpl(IntSummaryStatistics::new, (intSummaryStatistics, o)/* java.util.IntSummaryStatistics,java.lang.Object, */ -> intSummaryStatistics.accept(p0.applyAsInt(o)), (intSummaryStatistics2, other)/* java.util.IntSummaryStatistics,java.util.IntSummaryStatistics, */ -> {
            intSummaryStatistics2.combine(other);
            return intSummaryStatistics2;
        }, Collectors.CH_ID);
    }
    
    public static <T> Collector<T, ?, LongSummaryStatistics> summarizingLong(ToLongFunction<? super T> toLongFunction) {
        return new Collectors.CollectorImpl(LongSummaryStatistics::new, (longSummaryStatistics, o)/* java.util.LongSummaryStatistics,java.lang.Object, */ -> longSummaryStatistics.accept(p0.applyAsLong(o)), (longSummaryStatistics2, other)/* java.util.LongSummaryStatistics,java.util.LongSummaryStatistics, */ -> {
            longSummaryStatistics2.combine(other);
            return longSummaryStatistics2;
        }, Collectors.CH_ID);
    }
    
    public static <T> Collector<T, ?, DoubleSummaryStatistics> summarizingDouble(ToDoubleFunction<? super T> toDoubleFunction) {
        return new Collectors.CollectorImpl(DoubleSummaryStatistics::new, (doubleSummaryStatistics, o)/* java.util.DoubleSummaryStatistics,java.lang.Object, */ -> doubleSummaryStatistics.accept(p0.applyAsDouble(o)), (doubleSummaryStatistics2, other)/* java.util.DoubleSummaryStatistics,java.util.DoubleSummaryStatistics, */ -> {
            doubleSummaryStatistics2.combine(other);
            return doubleSummaryStatistics2;
        }, Collectors.CH_ID);
    }
    
    static Function access$000() {
        return castingIdentity();
    }
    
    static {
        CH_CONCURRENT_ID = Collections.unmodifiableSet(EnumSet.of(Collector.Characteristics.CONCURRENT, Collector.Characteristics.UNORDERED, Collector.Characteristics.IDENTITY_FINISH));
        CH_CONCURRENT_NOID = Collections.unmodifiableSet(EnumSet.of(Collector.Characteristics.CONCURRENT, Collector.Characteristics.UNORDERED));
        CH_ID = Collections.unmodifiableSet(EnumSet.of(Collector.Characteristics.IDENTITY_FINISH));
        CH_UNORDERED_ID = Collections.unmodifiableSet(EnumSet.of(Collector.Characteristics.UNORDERED, Collector.Characteristics.IDENTITY_FINISH));
        CH_NOID = Collections.emptySet();
    }
    
    static class CollectorImpl<T, A, R> implements Collector<T, A, R>
    {
        private final Supplier<A> supplier;
        private final BiConsumer<A, T> accumulator;
        private final BinaryOperator<A> combiner;
        private final Function<A, R> finisher;
        private final Set<Collector.Characteristics> characteristics;
        
        CollectorImpl(Supplier<A> supplier, BiConsumer<A, T> accumulator, BinaryOperator<A> combiner, Function<A, R> finisher, Set<Collector.Characteristics> characteristics) {
            this.supplier = supplier;
            this.accumulator = accumulator;
            this.combiner = combiner;
            this.finisher = finisher;
            this.characteristics = characteristics;
        }
        
        CollectorImpl(Supplier<A> supplier, BiConsumer<A, T> biConsumer, BinaryOperator<A> binaryOperator, Set<Collector.Characteristics> set) {
            this(supplier, biConsumer, binaryOperator, Collectors.access$000(), set);
        }
        
        @Override
        public BiConsumer<A, T> accumulator() {
            return this.accumulator;
        }
        
        @Override
        public Supplier<A> supplier() {
            return this.supplier;
        }
        
        @Override
        public BinaryOperator<A> combiner() {
            return this.combiner;
        }
        
        @Override
        public Function<A, R> finisher() {
            return this.finisher;
        }
        
        @Override
        public Set<Collector.Characteristics> characteristics() {
            return this.characteristics;
        }
    }
    
    private static final class Partition<T> extends AbstractMap<Boolean, T> implements Map<Boolean, T>
    {
        final T forTrue;
        final T forFalse;
        
        Partition(T forTrue, T forFalse) {
            this.forTrue = forTrue;
            this.forFalse = forFalse;
        }
        
        @Override
        public Set<Map.Entry<Boolean, T>> entrySet() {
            return new AbstractSet<Map.Entry<Boolean, T>>() {
                @Override
                public Iterator<Map.Entry<Boolean, T>> iterator() {
                    return Arrays.asList(new Map.Entry[] { new AbstractMap.SimpleImmutableEntry(Boolean.valueOf(false), Collectors.Partition.this.forFalse), new AbstractMap.SimpleImmutableEntry(Boolean.valueOf(true), Collectors.Partition.this.forTrue) }).iterator();
                }
                
                @Override
                public int size() {
                    return 2;
                }
            };
        }
    }
}
